summaryrefslogtreecommitdiff
path: root/tools/lpgen
diff options
context:
space:
mode:
authorRobert Pösel <robyer@seznam.cz>2013-01-25 13:39:41 +0000
committerRobert Pösel <robyer@seznam.cz>2013-01-25 13:39:41 +0000
commit95825760ed661034d5f7a6d635287944528b0cda (patch)
tree6fc544b86cba7cbf84984f9e0419542a83eebff7 /tools/lpgen
parent1f4ff098fa51b7eadb1b493c694da125b9468685 (diff)
translate.js: fixed working with duplicated translations in core file
git-svn-id: http://svn.miranda-ng.org/main/trunk@3280 1316c22d-e87f-b044-9b9b-93d7a3e3ba9c
Diffstat (limited to 'tools/lpgen')
-rw-r--r--tools/lpgen/translate.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/tools/lpgen/translate.js b/tools/lpgen/translate.js
index 3a03ab4d70..e550101eb4 100644
--- a/tools/lpgen/translate.js
+++ b/tools/lpgen/translate.js
@@ -183,8 +183,9 @@ while ((string = find.exec(translatefiletext)) != null) {
//first match as original string [....], is a key of dictionary, second match is a translation - item of key in dictionary
var key=string[1];
var item=string[2];
- //add key-item pair into dictionary
- dictionary.Add(key,item)
+ //add key-item pair into dictionary, if not exists already
+ if (!dictionary.Exists(key))
+ dictionary.Add(key,item);
}
//close file
translatefile.Close();